# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetRepositoryResult',
    'AwaitableGetRepositoryResult',
    'get_repository',
    'get_repository_output',
]

@pulumi.output_type
class GetRepositoryResult:
    """
    A collection of values returned by getRepository.
    """
    def __init__(__self__, branch_count=None, commit_count=None, compartment_id=None, default_branch=None, defined_tags=None, description=None, fields=None, freeform_tags=None, http_url=None, id=None, lifecyle_details=None, mirror_repository_configs=None, name=None, namespace=None, project_id=None, project_name=None, repository_id=None, repository_type=None, size_in_bytes=None, ssh_url=None, state=None, system_tags=None, time_created=None, time_updated=None, trigger_build_events=None):
        if branch_count and not isinstance(branch_count, int):
            raise TypeError("Expected argument 'branch_count' to be a int")
        pulumi.set(__self__, "branch_count", branch_count)
        if commit_count and not isinstance(commit_count, int):
            raise TypeError("Expected argument 'commit_count' to be a int")
        pulumi.set(__self__, "commit_count", commit_count)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if default_branch and not isinstance(default_branch, str):
            raise TypeError("Expected argument 'default_branch' to be a str")
        pulumi.set(__self__, "default_branch", default_branch)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if fields and not isinstance(fields, list):
            raise TypeError("Expected argument 'fields' to be a list")
        pulumi.set(__self__, "fields", fields)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if http_url and not isinstance(http_url, str):
            raise TypeError("Expected argument 'http_url' to be a str")
        pulumi.set(__self__, "http_url", http_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecyle_details and not isinstance(lifecyle_details, str):
            raise TypeError("Expected argument 'lifecyle_details' to be a str")
        pulumi.set(__self__, "lifecyle_details", lifecyle_details)
        if mirror_repository_configs and not isinstance(mirror_repository_configs, list):
            raise TypeError("Expected argument 'mirror_repository_configs' to be a list")
        pulumi.set(__self__, "mirror_repository_configs", mirror_repository_configs)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if repository_id and not isinstance(repository_id, str):
            raise TypeError("Expected argument 'repository_id' to be a str")
        pulumi.set(__self__, "repository_id", repository_id)
        if repository_type and not isinstance(repository_type, str):
            raise TypeError("Expected argument 'repository_type' to be a str")
        pulumi.set(__self__, "repository_type", repository_type)
        if size_in_bytes and not isinstance(size_in_bytes, str):
            raise TypeError("Expected argument 'size_in_bytes' to be a str")
        pulumi.set(__self__, "size_in_bytes", size_in_bytes)
        if ssh_url and not isinstance(ssh_url, str):
            raise TypeError("Expected argument 'ssh_url' to be a str")
        pulumi.set(__self__, "ssh_url", ssh_url)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if trigger_build_events and not isinstance(trigger_build_events, list):
            raise TypeError("Expected argument 'trigger_build_events' to be a list")
        pulumi.set(__self__, "trigger_build_events", trigger_build_events)

    @property
    @pulumi.getter(name="branchCount")
    def branch_count(self) -> int:
        """
        The count of the branches present in the repository.
        """
        return pulumi.get(self, "branch_count")

    @property
    @pulumi.getter(name="commitCount")
    def commit_count(self) -> int:
        """
        The count of the commits present in the repository.
        """
        return pulumi.get(self, "commit_count")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the repository's compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="defaultBranch")
    def default_branch(self) -> str:
        """
        The default branch of the repository.
        """
        return pulumi.get(self, "default_branch")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Details of the repository. Avoid entering confidential information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def fields(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "fields")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="httpUrl")
    def http_url(self) -> str:
        """
        HTTP URL that you use to git clone, pull and push.
        """
        return pulumi.get(self, "http_url")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the repository. This value is unique and immutable.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecyleDetails")
    def lifecyle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecyle_details")

    @property
    @pulumi.getter(name="mirrorRepositoryConfigs")
    def mirror_repository_configs(self) -> Sequence['outputs.GetRepositoryMirrorRepositoryConfigResult']:
        """
        Configuration information for mirroring the repository.
        """
        return pulumi.get(self, "mirror_repository_configs")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Unique name of a repository. This value is mutable.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        Tenancy unique namespace.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The OCID of the DevOps project containing the repository.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        Unique project name in a namespace.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> str:
        return pulumi.get(self, "repository_id")

    @property
    @pulumi.getter(name="repositoryType")
    def repository_type(self) -> str:
        """
        Type of repository: MIRRORED - Repository created by mirroring an existing repository. HOSTED - Repository created and hosted using Oracle Cloud Infrastructure DevOps code repository.
        """
        return pulumi.get(self, "repository_type")

    @property
    @pulumi.getter(name="sizeInBytes")
    def size_in_bytes(self) -> str:
        """
        The size of the repository in bytes.
        """
        return pulumi.get(self, "size_in_bytes")

    @property
    @pulumi.getter(name="sshUrl")
    def ssh_url(self) -> str:
        """
        SSH URL that you use to git clone, pull and push.
        """
        return pulumi.get(self, "ssh_url")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the repository.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the repository was created. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the repository was updated. Format defined by [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339).
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="triggerBuildEvents")
    def trigger_build_events(self) -> Sequence[str]:
        """
        Trigger build events supported for this repository: PUSH - Build is triggered when a push event occurs. COMMIT_UPDATES - Build is triggered when new commits are mirrored into a repository.
        """
        return pulumi.get(self, "trigger_build_events")


class AwaitableGetRepositoryResult(GetRepositoryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryResult(
            branch_count=self.branch_count,
            commit_count=self.commit_count,
            compartment_id=self.compartment_id,
            default_branch=self.default_branch,
            defined_tags=self.defined_tags,
            description=self.description,
            fields=self.fields,
            freeform_tags=self.freeform_tags,
            http_url=self.http_url,
            id=self.id,
            lifecyle_details=self.lifecyle_details,
            mirror_repository_configs=self.mirror_repository_configs,
            name=self.name,
            namespace=self.namespace,
            project_id=self.project_id,
            project_name=self.project_name,
            repository_id=self.repository_id,
            repository_type=self.repository_type,
            size_in_bytes=self.size_in_bytes,
            ssh_url=self.ssh_url,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated,
            trigger_build_events=self.trigger_build_events)


def get_repository(fields: Optional[Sequence[str]] = None,
                   repository_id: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryResult:
    """
    This data source provides details about a specific Repository resource in Oracle Cloud Infrastructure Devops service.

    Retrieves a repository by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository = oci.DevOps.get_repository(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] fields: Fields parameter can contain multiple flags useful in deciding the API functionality.
    :param str repository_id: Unique repository identifier.
    """
    __args__ = dict()
    __args__['fields'] = fields
    __args__['repositoryId'] = repository_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DevOps/getRepository:getRepository', __args__, opts=opts, typ=GetRepositoryResult).value

    return AwaitableGetRepositoryResult(
        branch_count=__ret__.branch_count,
        commit_count=__ret__.commit_count,
        compartment_id=__ret__.compartment_id,
        default_branch=__ret__.default_branch,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        fields=__ret__.fields,
        freeform_tags=__ret__.freeform_tags,
        http_url=__ret__.http_url,
        id=__ret__.id,
        lifecyle_details=__ret__.lifecyle_details,
        mirror_repository_configs=__ret__.mirror_repository_configs,
        name=__ret__.name,
        namespace=__ret__.namespace,
        project_id=__ret__.project_id,
        project_name=__ret__.project_name,
        repository_id=__ret__.repository_id,
        repository_type=__ret__.repository_type,
        size_in_bytes=__ret__.size_in_bytes,
        ssh_url=__ret__.ssh_url,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated,
        trigger_build_events=__ret__.trigger_build_events)


@_utilities.lift_output_func(get_repository)
def get_repository_output(fields: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                          repository_id: Optional[pulumi.Input[str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRepositoryResult]:
    """
    This data source provides details about a specific Repository resource in Oracle Cloud Infrastructure Devops service.

    Retrieves a repository by identifier.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository = oci.DevOps.get_repository(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] fields: Fields parameter can contain multiple flags useful in deciding the API functionality.
    :param str repository_id: Unique repository identifier.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMaskingPoliciesMaskingColumnResult',
    'AwaitableGetMaskingPoliciesMaskingColumnResult',
    'get_masking_policies_masking_column',
    'get_masking_policies_masking_column_output',
]

@pulumi.output_type
class GetMaskingPoliciesMaskingColumnResult:
    """
    A collection of values returned by getMaskingPoliciesMaskingColumn.
    """
    def __init__(__self__, child_columns=None, column_name=None, data_type=None, id=None, is_masking_enabled=None, key=None, lifecycle_details=None, masking_column_group=None, masking_column_key=None, masking_formats=None, masking_policy_id=None, object=None, object_type=None, schema_name=None, sensitive_type_id=None, state=None, time_created=None, time_updated=None):
        if child_columns and not isinstance(child_columns, list):
            raise TypeError("Expected argument 'child_columns' to be a list")
        pulumi.set(__self__, "child_columns", child_columns)
        if column_name and not isinstance(column_name, str):
            raise TypeError("Expected argument 'column_name' to be a str")
        pulumi.set(__self__, "column_name", column_name)
        if data_type and not isinstance(data_type, str):
            raise TypeError("Expected argument 'data_type' to be a str")
        pulumi.set(__self__, "data_type", data_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_masking_enabled and not isinstance(is_masking_enabled, bool):
            raise TypeError("Expected argument 'is_masking_enabled' to be a bool")
        pulumi.set(__self__, "is_masking_enabled", is_masking_enabled)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if masking_column_group and not isinstance(masking_column_group, str):
            raise TypeError("Expected argument 'masking_column_group' to be a str")
        pulumi.set(__self__, "masking_column_group", masking_column_group)
        if masking_column_key and not isinstance(masking_column_key, str):
            raise TypeError("Expected argument 'masking_column_key' to be a str")
        pulumi.set(__self__, "masking_column_key", masking_column_key)
        if masking_formats and not isinstance(masking_formats, list):
            raise TypeError("Expected argument 'masking_formats' to be a list")
        pulumi.set(__self__, "masking_formats", masking_formats)
        if masking_policy_id and not isinstance(masking_policy_id, str):
            raise TypeError("Expected argument 'masking_policy_id' to be a str")
        pulumi.set(__self__, "masking_policy_id", masking_policy_id)
        if object and not isinstance(object, str):
            raise TypeError("Expected argument 'object' to be a str")
        pulumi.set(__self__, "object", object)
        if object_type and not isinstance(object_type, str):
            raise TypeError("Expected argument 'object_type' to be a str")
        pulumi.set(__self__, "object_type", object_type)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)
        if sensitive_type_id and not isinstance(sensitive_type_id, str):
            raise TypeError("Expected argument 'sensitive_type_id' to be a str")
        pulumi.set(__self__, "sensitive_type_id", sensitive_type_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="childColumns")
    def child_columns(self) -> Sequence[str]:
        """
        An array of child columns that are in referential relationship with the masking column.
        """
        return pulumi.get(self, "child_columns")

    @property
    @pulumi.getter(name="columnName")
    def column_name(self) -> str:
        """
        The name of the substitution column.
        """
        return pulumi.get(self, "column_name")

    @property
    @pulumi.getter(name="dataType")
    def data_type(self) -> str:
        """
        The data type of the masking column.
        """
        return pulumi.get(self, "data_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isMaskingEnabled")
    def is_masking_enabled(self) -> bool:
        """
        Indicates if data masking is enabled for the masking column.
        """
        return pulumi.get(self, "is_masking_enabled")

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        The unique key that identifies the masking column. It's numeric and unique within a masking policy.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        Details about the current state of the masking column.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="maskingColumnGroup")
    def masking_column_group(self) -> str:
        """
        The group of the masking column. All the columns in a group are masked together to ensure  that the masked data across these columns continue to retain the same logical relationship.  For more details, check <a href=https://docs.oracle.com/en/cloud/paas/data-safe/udscs/group-masking1.html#GUID-755056B9-9540-48C0-9491-262A44A85037>Group Masking in the Data Safe documentation.</a>
        """
        return pulumi.get(self, "masking_column_group")

    @property
    @pulumi.getter(name="maskingColumnKey")
    def masking_column_key(self) -> str:
        return pulumi.get(self, "masking_column_key")

    @property
    @pulumi.getter(name="maskingFormats")
    def masking_formats(self) -> Sequence['outputs.GetMaskingPoliciesMaskingColumnMaskingFormatResult']:
        """
        An array of masking formats assigned to the masking column.
        """
        return pulumi.get(self, "masking_formats")

    @property
    @pulumi.getter(name="maskingPolicyId")
    def masking_policy_id(self) -> str:
        """
        The OCID of the masking policy that contains the masking column.
        """
        return pulumi.get(self, "masking_policy_id")

    @property
    @pulumi.getter
    def object(self) -> str:
        """
        The name of the object (table or editioning view) that contains the database column.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter(name="objectType")
    def object_type(self) -> str:
        """
        The type of the object that contains the database column.
        """
        return pulumi.get(self, "object_type")

    @property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> str:
        """
        The name of the schema that contains the database column.
        """
        return pulumi.get(self, "schema_name")

    @property
    @pulumi.getter(name="sensitiveTypeId")
    def sensitive_type_id(self) -> str:
        """
        The OCID of the sensitive type associated with the masking column.
        """
        return pulumi.get(self, "sensitive_type_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the masking column.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the masking column was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the masking column was last updated, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetMaskingPoliciesMaskingColumnResult(GetMaskingPoliciesMaskingColumnResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaskingPoliciesMaskingColumnResult(
            child_columns=self.child_columns,
            column_name=self.column_name,
            data_type=self.data_type,
            id=self.id,
            is_masking_enabled=self.is_masking_enabled,
            key=self.key,
            lifecycle_details=self.lifecycle_details,
            masking_column_group=self.masking_column_group,
            masking_column_key=self.masking_column_key,
            masking_formats=self.masking_formats,
            masking_policy_id=self.masking_policy_id,
            object=self.object,
            object_type=self.object_type,
            schema_name=self.schema_name,
            sensitive_type_id=self.sensitive_type_id,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_masking_policies_masking_column(masking_column_key: Optional[str] = None,
                                        masking_policy_id: Optional[str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaskingPoliciesMaskingColumnResult:
    """
    This data source provides details about a specific Masking Policies Masking Column resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified masking column.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_masking_policies_masking_column = oci.DataSafe.get_masking_policies_masking_column(masking_column_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str masking_column_key: The unique key that identifies the masking column. It's numeric and unique within a masking policy.
    :param str masking_policy_id: The OCID of the masking policy.
    """
    __args__ = dict()
    __args__['maskingColumnKey'] = masking_column_key
    __args__['maskingPolicyId'] = masking_policy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getMaskingPoliciesMaskingColumn:getMaskingPoliciesMaskingColumn', __args__, opts=opts, typ=GetMaskingPoliciesMaskingColumnResult).value

    return AwaitableGetMaskingPoliciesMaskingColumnResult(
        child_columns=__ret__.child_columns,
        column_name=__ret__.column_name,
        data_type=__ret__.data_type,
        id=__ret__.id,
        is_masking_enabled=__ret__.is_masking_enabled,
        key=__ret__.key,
        lifecycle_details=__ret__.lifecycle_details,
        masking_column_group=__ret__.masking_column_group,
        masking_column_key=__ret__.masking_column_key,
        masking_formats=__ret__.masking_formats,
        masking_policy_id=__ret__.masking_policy_id,
        object=__ret__.object,
        object_type=__ret__.object_type,
        schema_name=__ret__.schema_name,
        sensitive_type_id=__ret__.sensitive_type_id,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_masking_policies_masking_column)
def get_masking_policies_masking_column_output(masking_column_key: Optional[pulumi.Input[str]] = None,
                                               masking_policy_id: Optional[pulumi.Input[str]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMaskingPoliciesMaskingColumnResult]:
    """
    This data source provides details about a specific Masking Policies Masking Column resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified masking column.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_masking_policies_masking_column = oci.DataSafe.get_masking_policies_masking_column(masking_column_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str masking_column_key: The unique key that identifies the masking column. It's numeric and unique within a masking policy.
    :param str masking_policy_id: The OCID of the masking policy.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetVmClusterPatchHistoryEntryResult',
    'AwaitableGetVmClusterPatchHistoryEntryResult',
    'get_vm_cluster_patch_history_entry',
    'get_vm_cluster_patch_history_entry_output',
]

@pulumi.output_type
class GetVmClusterPatchHistoryEntryResult:
    """
    A collection of values returned by getVmClusterPatchHistoryEntry.
    """
    def __init__(__self__, action=None, id=None, lifecycle_details=None, patch_history_entry_id=None, patch_id=None, state=None, time_ended=None, time_started=None, vm_cluster_id=None):
        if action and not isinstance(action, str):
            raise TypeError("Expected argument 'action' to be a str")
        pulumi.set(__self__, "action", action)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if patch_history_entry_id and not isinstance(patch_history_entry_id, str):
            raise TypeError("Expected argument 'patch_history_entry_id' to be a str")
        pulumi.set(__self__, "patch_history_entry_id", patch_history_entry_id)
        if patch_id and not isinstance(patch_id, str):
            raise TypeError("Expected argument 'patch_id' to be a str")
        pulumi.set(__self__, "patch_id", patch_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_ended and not isinstance(time_ended, str):
            raise TypeError("Expected argument 'time_ended' to be a str")
        pulumi.set(__self__, "time_ended", time_ended)
        if time_started and not isinstance(time_started, str):
            raise TypeError("Expected argument 'time_started' to be a str")
        pulumi.set(__self__, "time_started", time_started)
        if vm_cluster_id and not isinstance(vm_cluster_id, str):
            raise TypeError("Expected argument 'vm_cluster_id' to be a str")
        pulumi.set(__self__, "vm_cluster_id", vm_cluster_id)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        The action being performed or was completed.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A descriptive text associated with the lifecycleState. Typically contains additional displayable text.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="patchHistoryEntryId")
    def patch_history_entry_id(self) -> str:
        return pulumi.get(self, "patch_history_entry_id")

    @property
    @pulumi.getter(name="patchId")
    def patch_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the patch.
        """
        return pulumi.get(self, "patch_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the action.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeEnded")
    def time_ended(self) -> str:
        """
        The date and time when the patch action completed
        """
        return pulumi.get(self, "time_ended")

    @property
    @pulumi.getter(name="timeStarted")
    def time_started(self) -> str:
        """
        The date and time when the patch action started.
        """
        return pulumi.get(self, "time_started")

    @property
    @pulumi.getter(name="vmClusterId")
    def vm_cluster_id(self) -> str:
        return pulumi.get(self, "vm_cluster_id")


class AwaitableGetVmClusterPatchHistoryEntryResult(GetVmClusterPatchHistoryEntryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVmClusterPatchHistoryEntryResult(
            action=self.action,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            patch_history_entry_id=self.patch_history_entry_id,
            patch_id=self.patch_id,
            state=self.state,
            time_ended=self.time_ended,
            time_started=self.time_started,
            vm_cluster_id=self.vm_cluster_id)


def get_vm_cluster_patch_history_entry(patch_history_entry_id: Optional[str] = None,
                                       vm_cluster_id: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVmClusterPatchHistoryEntryResult:
    """
    This data source provides details about a specific Vm Cluster Patch History Entry resource in Oracle Cloud Infrastructure Database service.

    Gets the patch history details for the specified patch history entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vm_cluster_patch_history_entry = oci.Database.get_vm_cluster_patch_history_entry(patch_history_entry_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vm_cluster_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str patch_history_entry_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the patch history entry.
    :param str vm_cluster_id: The VM cluster [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['patchHistoryEntryId'] = patch_history_entry_id
    __args__['vmClusterId'] = vm_cluster_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getVmClusterPatchHistoryEntry:getVmClusterPatchHistoryEntry', __args__, opts=opts, typ=GetVmClusterPatchHistoryEntryResult).value

    return AwaitableGetVmClusterPatchHistoryEntryResult(
        action=__ret__.action,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        patch_history_entry_id=__ret__.patch_history_entry_id,
        patch_id=__ret__.patch_id,
        state=__ret__.state,
        time_ended=__ret__.time_ended,
        time_started=__ret__.time_started,
        vm_cluster_id=__ret__.vm_cluster_id)


@_utilities.lift_output_func(get_vm_cluster_patch_history_entry)
def get_vm_cluster_patch_history_entry_output(patch_history_entry_id: Optional[pulumi.Input[str]] = None,
                                              vm_cluster_id: Optional[pulumi.Input[str]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVmClusterPatchHistoryEntryResult]:
    """
    This data source provides details about a specific Vm Cluster Patch History Entry resource in Oracle Cloud Infrastructure Database service.

    Gets the patch history details for the specified patch history entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vm_cluster_patch_history_entry = oci.Database.get_vm_cluster_patch_history_entry(patch_history_entry_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vm_cluster_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str patch_history_entry_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the patch history entry.
    :param str vm_cluster_id: The VM cluster [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'SessionKeyDetailsArgs',
    'SessionTargetResourceDetailsArgs',
    'GetBastionsFilterArgs',
    'GetSessionsFilterArgs',
]

@pulumi.input_type
class SessionKeyDetailsArgs:
    def __init__(__self__, *,
                 public_key_content: pulumi.Input[str]):
        """
        :param pulumi.Input[str] public_key_content: The public key in OpenSSH format of the SSH key pair for the session. When you connect to the session, you must provide the private key of the same SSH key pair.
        """
        pulumi.set(__self__, "public_key_content", public_key_content)

    @property
    @pulumi.getter(name="publicKeyContent")
    def public_key_content(self) -> pulumi.Input[str]:
        """
        The public key in OpenSSH format of the SSH key pair for the session. When you connect to the session, you must provide the private key of the same SSH key pair.
        """
        return pulumi.get(self, "public_key_content")

    @public_key_content.setter
    def public_key_content(self, value: pulumi.Input[str]):
        pulumi.set(self, "public_key_content", value)


@pulumi.input_type
class SessionTargetResourceDetailsArgs:
    def __init__(__self__, *,
                 session_type: pulumi.Input[str],
                 target_resource_display_name: Optional[pulumi.Input[str]] = None,
                 target_resource_fqdn: Optional[pulumi.Input[str]] = None,
                 target_resource_id: Optional[pulumi.Input[str]] = None,
                 target_resource_operating_system_user_name: Optional[pulumi.Input[str]] = None,
                 target_resource_port: Optional[pulumi.Input[int]] = None,
                 target_resource_private_ip_address: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] session_type: The session type.
        :param pulumi.Input[str] target_resource_display_name: The display name of the target Compute instance that the session connects to.
        :param pulumi.Input[str] target_resource_fqdn: The Fully Qualified Domain Name of the target resource that the session connects to.
        :param pulumi.Input[str] target_resource_id: The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.
        :param pulumi.Input[str] target_resource_operating_system_user_name: The name of the user on the target resource operating system that the session uses for the connection.
        :param pulumi.Input[int] target_resource_port: The port number to connect to on the target resource.
        :param pulumi.Input[str] target_resource_private_ip_address: The private IP address of the target resource that the session connects to.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "session_type", session_type)
        if target_resource_display_name is not None:
            pulumi.set(__self__, "target_resource_display_name", target_resource_display_name)
        if target_resource_fqdn is not None:
            pulumi.set(__self__, "target_resource_fqdn", target_resource_fqdn)
        if target_resource_id is not None:
            pulumi.set(__self__, "target_resource_id", target_resource_id)
        if target_resource_operating_system_user_name is not None:
            pulumi.set(__self__, "target_resource_operating_system_user_name", target_resource_operating_system_user_name)
        if target_resource_port is not None:
            pulumi.set(__self__, "target_resource_port", target_resource_port)
        if target_resource_private_ip_address is not None:
            pulumi.set(__self__, "target_resource_private_ip_address", target_resource_private_ip_address)

    @property
    @pulumi.getter(name="sessionType")
    def session_type(self) -> pulumi.Input[str]:
        """
        The session type.
        """
        return pulumi.get(self, "session_type")

    @session_type.setter
    def session_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "session_type", value)

    @property
    @pulumi.getter(name="targetResourceDisplayName")
    def target_resource_display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The display name of the target Compute instance that the session connects to.
        """
        return pulumi.get(self, "target_resource_display_name")

    @target_resource_display_name.setter
    def target_resource_display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_resource_display_name", value)

    @property
    @pulumi.getter(name="targetResourceFqdn")
    def target_resource_fqdn(self) -> Optional[pulumi.Input[str]]:
        """
        The Fully Qualified Domain Name of the target resource that the session connects to.
        """
        return pulumi.get(self, "target_resource_fqdn")

    @target_resource_fqdn.setter
    def target_resource_fqdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_resource_fqdn", value)

    @property
    @pulumi.getter(name="targetResourceId")
    def target_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.
        """
        return pulumi.get(self, "target_resource_id")

    @target_resource_id.setter
    def target_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_resource_id", value)

    @property
    @pulumi.getter(name="targetResourceOperatingSystemUserName")
    def target_resource_operating_system_user_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the user on the target resource operating system that the session uses for the connection.
        """
        return pulumi.get(self, "target_resource_operating_system_user_name")

    @target_resource_operating_system_user_name.setter
    def target_resource_operating_system_user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_resource_operating_system_user_name", value)

    @property
    @pulumi.getter(name="targetResourcePort")
    def target_resource_port(self) -> Optional[pulumi.Input[int]]:
        """
        The port number to connect to on the target resource.
        """
        return pulumi.get(self, "target_resource_port")

    @target_resource_port.setter
    def target_resource_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_resource_port", value)

    @property
    @pulumi.getter(name="targetResourcePrivateIpAddress")
    def target_resource_private_ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        The private IP address of the target resource that the session connects to.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "target_resource_private_ip_address")

    @target_resource_private_ip_address.setter
    def target_resource_private_ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_resource_private_ip_address", value)


@pulumi.input_type
class GetBastionsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: A filter to return only resources that match the entire name given.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A filter to return only resources that match the entire name given.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSessionsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BlockchainPlatformArgs', 'BlockchainPlatform']

@pulumi.input_type
class BlockchainPlatformArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 compute_shape: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 idcs_access_token: pulumi.Input[str],
                 platform_role: pulumi.Input[str],
                 ca_cert_archive_text: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 federated_user_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 is_byol: Optional[pulumi.Input[bool]] = None,
                 load_balancer_shape: Optional[pulumi.Input[str]] = None,
                 platform_version: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input['BlockchainPlatformReplicasArgs']] = None,
                 storage_size_in_tbs: Optional[pulumi.Input[float]] = None,
                 total_ocpu_capacity: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a BlockchainPlatform resource.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[str] compute_shape: Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        :param pulumi.Input[str] display_name: Platform Instance Display name, can be renamed
        :param pulumi.Input[str] idcs_access_token: IDCS access token with Identity Domain Administrator role
        :param pulumi.Input[str] platform_role: Role of platform - founder or participant
        :param pulumi.Input[str] ca_cert_archive_text: Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) Platform Instance Description
        :param pulumi.Input[str] federated_user_id: Identifier for a federated user
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] is_byol: Bring your own license
        :param pulumi.Input[str] load_balancer_shape: (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] platform_version: Platform version
        :param pulumi.Input['BlockchainPlatformReplicasArgs'] replicas: Number of replicas of service components like Rest Proxy, CA and Console
        :param pulumi.Input[float] storage_size_in_tbs: Storage size in TBs
        :param pulumi.Input[int] total_ocpu_capacity: Number of total OCPUs allocated to the platform cluster
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "compute_shape", compute_shape)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        pulumi.set(__self__, "platform_role", platform_role)
        if ca_cert_archive_text is not None:
            pulumi.set(__self__, "ca_cert_archive_text", ca_cert_archive_text)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if federated_user_id is not None:
            pulumi.set(__self__, "federated_user_id", federated_user_id)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if is_byol is not None:
            pulumi.set(__self__, "is_byol", is_byol)
        if load_balancer_shape is not None:
            pulumi.set(__self__, "load_balancer_shape", load_balancer_shape)
        if platform_version is not None:
            pulumi.set(__self__, "platform_version", platform_version)
        if replicas is not None:
            pulumi.set(__self__, "replicas", replicas)
        if storage_size_in_tbs is not None:
            pulumi.set(__self__, "storage_size_in_tbs", storage_size_in_tbs)
        if total_ocpu_capacity is not None:
            pulumi.set(__self__, "total_ocpu_capacity", total_ocpu_capacity)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="computeShape")
    def compute_shape(self) -> pulumi.Input[str]:
        """
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        """
        return pulumi.get(self, "compute_shape")

    @compute_shape.setter
    def compute_shape(self, value: pulumi.Input[str]):
        pulumi.set(self, "compute_shape", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        Platform Instance Display name, can be renamed
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> pulumi.Input[str]:
        """
        IDCS access token with Identity Domain Administrator role
        """
        return pulumi.get(self, "idcs_access_token")

    @idcs_access_token.setter
    def idcs_access_token(self, value: pulumi.Input[str]):
        pulumi.set(self, "idcs_access_token", value)

    @property
    @pulumi.getter(name="platformRole")
    def platform_role(self) -> pulumi.Input[str]:
        """
        Role of platform - founder or participant
        """
        return pulumi.get(self, "platform_role")

    @platform_role.setter
    def platform_role(self, value: pulumi.Input[str]):
        pulumi.set(self, "platform_role", value)

    @property
    @pulumi.getter(name="caCertArchiveText")
    def ca_cert_archive_text(self) -> Optional[pulumi.Input[str]]:
        """
        Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        """
        return pulumi.get(self, "ca_cert_archive_text")

    @ca_cert_archive_text.setter
    def ca_cert_archive_text(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ca_cert_archive_text", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Platform Instance Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="federatedUserId")
    def federated_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier for a federated user
        """
        return pulumi.get(self, "federated_user_id")

    @federated_user_id.setter
    def federated_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "federated_user_id", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="isByol")
    def is_byol(self) -> Optional[pulumi.Input[bool]]:
        """
        Bring your own license
        """
        return pulumi.get(self, "is_byol")

    @is_byol.setter
    def is_byol(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_byol", value)

    @property
    @pulumi.getter(name="loadBalancerShape")
    def load_balancer_shape(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "load_balancer_shape")

    @load_balancer_shape.setter
    def load_balancer_shape(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_balancer_shape", value)

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> Optional[pulumi.Input[str]]:
        """
        Platform version
        """
        return pulumi.get(self, "platform_version")

    @platform_version.setter
    def platform_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_version", value)

    @property
    @pulumi.getter
    def replicas(self) -> Optional[pulumi.Input['BlockchainPlatformReplicasArgs']]:
        """
        Number of replicas of service components like Rest Proxy, CA and Console
        """
        return pulumi.get(self, "replicas")

    @replicas.setter
    def replicas(self, value: Optional[pulumi.Input['BlockchainPlatformReplicasArgs']]):
        pulumi.set(self, "replicas", value)

    @property
    @pulumi.getter(name="storageSizeInTbs")
    def storage_size_in_tbs(self) -> Optional[pulumi.Input[float]]:
        """
        Storage size in TBs
        """
        return pulumi.get(self, "storage_size_in_tbs")

    @storage_size_in_tbs.setter
    def storage_size_in_tbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "storage_size_in_tbs", value)

    @property
    @pulumi.getter(name="totalOcpuCapacity")
    def total_ocpu_capacity(self) -> Optional[pulumi.Input[int]]:
        """
        Number of total OCPUs allocated to the platform cluster
        """
        return pulumi.get(self, "total_ocpu_capacity")

    @total_ocpu_capacity.setter
    def total_ocpu_capacity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_ocpu_capacity", value)


@pulumi.input_type
class _BlockchainPlatformState:
    def __init__(__self__, *,
                 ca_cert_archive_text: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 component_details: Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformComponentDetailArgs']]]] = None,
                 compute_shape: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 federated_user_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 host_ocpu_utilization_infos: Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformHostOcpuUtilizationInfoArgs']]]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 is_byol: Optional[pulumi.Input[bool]] = None,
                 is_multi_ad: Optional[pulumi.Input[bool]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 load_balancer_shape: Optional[pulumi.Input[str]] = None,
                 platform_role: Optional[pulumi.Input[str]] = None,
                 platform_shape_type: Optional[pulumi.Input[str]] = None,
                 platform_version: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input['BlockchainPlatformReplicasArgs']] = None,
                 service_endpoint: Optional[pulumi.Input[str]] = None,
                 service_version: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 storage_size_in_tbs: Optional[pulumi.Input[float]] = None,
                 storage_used_in_tbs: Optional[pulumi.Input[float]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 total_ocpu_capacity: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering BlockchainPlatform resources.
        :param pulumi.Input[str] ca_cert_archive_text: Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformComponentDetailArgs']]] component_details: Blockchain Platform component details.
        :param pulumi.Input[str] compute_shape: Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) Platform Instance Description
        :param pulumi.Input[str] display_name: Platform Instance Display name, can be renamed
        :param pulumi.Input[str] federated_user_id: Identifier for a federated user
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformHostOcpuUtilizationInfoArgs']]] host_ocpu_utilization_infos: List of OcpuUtilization for all hosts
        :param pulumi.Input[str] idcs_access_token: IDCS access token with Identity Domain Administrator role
        :param pulumi.Input[bool] is_byol: Bring your own license
        :param pulumi.Input[bool] is_multi_ad: True for multi-AD blockchain plaforms, false for single-AD
        :param pulumi.Input[str] lifecycle_details: An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] load_balancer_shape: (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] platform_role: Role of platform - founder or participant
        :param pulumi.Input[str] platform_shape_type: Type of Platform shape - DEFAULT or CUSTOM
        :param pulumi.Input[str] platform_version: Platform version
        :param pulumi.Input['BlockchainPlatformReplicasArgs'] replicas: Number of replicas of service components like Rest Proxy, CA and Console
        :param pulumi.Input[str] service_endpoint: Service endpoint URL, valid post-provisioning
        :param pulumi.Input[str] service_version: The version of the Platform Instance.
        :param pulumi.Input[str] state: The current state of the Platform Instance.
        :param pulumi.Input[float] storage_size_in_tbs: Storage size in TBs
        :param pulumi.Input[float] storage_used_in_tbs: Storage used in TBs
        :param pulumi.Input[str] time_created: The time the the Platform Instance was created. An RFC3339 formatted datetime string
        :param pulumi.Input[str] time_updated: The time the Platform Instance was updated. An RFC3339 formatted datetime string
        :param pulumi.Input[int] total_ocpu_capacity: Number of total OCPUs allocated to the platform cluster
        """
        if ca_cert_archive_text is not None:
            pulumi.set(__self__, "ca_cert_archive_text", ca_cert_archive_text)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if component_details is not None:
            pulumi.set(__self__, "component_details", component_details)
        if compute_shape is not None:
            pulumi.set(__self__, "compute_shape", compute_shape)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if federated_user_id is not None:
            pulumi.set(__self__, "federated_user_id", federated_user_id)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if host_ocpu_utilization_infos is not None:
            pulumi.set(__self__, "host_ocpu_utilization_infos", host_ocpu_utilization_infos)
        if idcs_access_token is not None:
            pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        if is_byol is not None:
            pulumi.set(__self__, "is_byol", is_byol)
        if is_multi_ad is not None:
            pulumi.set(__self__, "is_multi_ad", is_multi_ad)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if load_balancer_shape is not None:
            pulumi.set(__self__, "load_balancer_shape", load_balancer_shape)
        if platform_role is not None:
            pulumi.set(__self__, "platform_role", platform_role)
        if platform_shape_type is not None:
            pulumi.set(__self__, "platform_shape_type", platform_shape_type)
        if platform_version is not None:
            pulumi.set(__self__, "platform_version", platform_version)
        if replicas is not None:
            pulumi.set(__self__, "replicas", replicas)
        if service_endpoint is not None:
            pulumi.set(__self__, "service_endpoint", service_endpoint)
        if service_version is not None:
            pulumi.set(__self__, "service_version", service_version)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if storage_size_in_tbs is not None:
            pulumi.set(__self__, "storage_size_in_tbs", storage_size_in_tbs)
        if storage_used_in_tbs is not None:
            pulumi.set(__self__, "storage_used_in_tbs", storage_used_in_tbs)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if total_ocpu_capacity is not None:
            pulumi.set(__self__, "total_ocpu_capacity", total_ocpu_capacity)

    @property
    @pulumi.getter(name="caCertArchiveText")
    def ca_cert_archive_text(self) -> Optional[pulumi.Input[str]]:
        """
        Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        """
        return pulumi.get(self, "ca_cert_archive_text")

    @ca_cert_archive_text.setter
    def ca_cert_archive_text(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ca_cert_archive_text", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="componentDetails")
    def component_details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformComponentDetailArgs']]]]:
        """
        Blockchain Platform component details.
        """
        return pulumi.get(self, "component_details")

    @component_details.setter
    def component_details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformComponentDetailArgs']]]]):
        pulumi.set(self, "component_details", value)

    @property
    @pulumi.getter(name="computeShape")
    def compute_shape(self) -> Optional[pulumi.Input[str]]:
        """
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        """
        return pulumi.get(self, "compute_shape")

    @compute_shape.setter
    def compute_shape(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compute_shape", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Platform Instance Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Platform Instance Display name, can be renamed
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="federatedUserId")
    def federated_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier for a federated user
        """
        return pulumi.get(self, "federated_user_id")

    @federated_user_id.setter
    def federated_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "federated_user_id", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="hostOcpuUtilizationInfos")
    def host_ocpu_utilization_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformHostOcpuUtilizationInfoArgs']]]]:
        """
        List of OcpuUtilization for all hosts
        """
        return pulumi.get(self, "host_ocpu_utilization_infos")

    @host_ocpu_utilization_infos.setter
    def host_ocpu_utilization_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockchainPlatformHostOcpuUtilizationInfoArgs']]]]):
        pulumi.set(self, "host_ocpu_utilization_infos", value)

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> Optional[pulumi.Input[str]]:
        """
        IDCS access token with Identity Domain Administrator role
        """
        return pulumi.get(self, "idcs_access_token")

    @idcs_access_token.setter
    def idcs_access_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idcs_access_token", value)

    @property
    @pulumi.getter(name="isByol")
    def is_byol(self) -> Optional[pulumi.Input[bool]]:
        """
        Bring your own license
        """
        return pulumi.get(self, "is_byol")

    @is_byol.setter
    def is_byol(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_byol", value)

    @property
    @pulumi.getter(name="isMultiAd")
    def is_multi_ad(self) -> Optional[pulumi.Input[bool]]:
        """
        True for multi-AD blockchain plaforms, false for single-AD
        """
        return pulumi.get(self, "is_multi_ad")

    @is_multi_ad.setter
    def is_multi_ad(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_multi_ad", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="loadBalancerShape")
    def load_balancer_shape(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "load_balancer_shape")

    @load_balancer_shape.setter
    def load_balancer_shape(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_balancer_shape", value)

    @property
    @pulumi.getter(name="platformRole")
    def platform_role(self) -> Optional[pulumi.Input[str]]:
        """
        Role of platform - founder or participant
        """
        return pulumi.get(self, "platform_role")

    @platform_role.setter
    def platform_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_role", value)

    @property
    @pulumi.getter(name="platformShapeType")
    def platform_shape_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of Platform shape - DEFAULT or CUSTOM
        """
        return pulumi.get(self, "platform_shape_type")

    @platform_shape_type.setter
    def platform_shape_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_shape_type", value)

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> Optional[pulumi.Input[str]]:
        """
        Platform version
        """
        return pulumi.get(self, "platform_version")

    @platform_version.setter
    def platform_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "platform_version", value)

    @property
    @pulumi.getter
    def replicas(self) -> Optional[pulumi.Input['BlockchainPlatformReplicasArgs']]:
        """
        Number of replicas of service components like Rest Proxy, CA and Console
        """
        return pulumi.get(self, "replicas")

    @replicas.setter
    def replicas(self, value: Optional[pulumi.Input['BlockchainPlatformReplicasArgs']]):
        pulumi.set(self, "replicas", value)

    @property
    @pulumi.getter(name="serviceEndpoint")
    def service_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Service endpoint URL, valid post-provisioning
        """
        return pulumi.get(self, "service_endpoint")

    @service_endpoint.setter
    def service_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_endpoint", value)

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the Platform Instance.
        """
        return pulumi.get(self, "service_version")

    @service_version.setter
    def service_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_version", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the Platform Instance.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="storageSizeInTbs")
    def storage_size_in_tbs(self) -> Optional[pulumi.Input[float]]:
        """
        Storage size in TBs
        """
        return pulumi.get(self, "storage_size_in_tbs")

    @storage_size_in_tbs.setter
    def storage_size_in_tbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "storage_size_in_tbs", value)

    @property
    @pulumi.getter(name="storageUsedInTbs")
    def storage_used_in_tbs(self) -> Optional[pulumi.Input[float]]:
        """
        Storage used in TBs
        """
        return pulumi.get(self, "storage_used_in_tbs")

    @storage_used_in_tbs.setter
    def storage_used_in_tbs(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "storage_used_in_tbs", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time the the Platform Instance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time the Platform Instance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter(name="totalOcpuCapacity")
    def total_ocpu_capacity(self) -> Optional[pulumi.Input[int]]:
        """
        Number of total OCPUs allocated to the platform cluster
        """
        return pulumi.get(self, "total_ocpu_capacity")

    @total_ocpu_capacity.setter
    def total_ocpu_capacity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_ocpu_capacity", value)


class BlockchainPlatform(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_cert_archive_text: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 compute_shape: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 federated_user_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 is_byol: Optional[pulumi.Input[bool]] = None,
                 load_balancer_shape: Optional[pulumi.Input[str]] = None,
                 platform_role: Optional[pulumi.Input[str]] = None,
                 platform_version: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[pulumi.InputType['BlockchainPlatformReplicasArgs']]] = None,
                 storage_size_in_tbs: Optional[pulumi.Input[float]] = None,
                 total_ocpu_capacity: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        This resource provides the Blockchain Platform resource in Oracle Cloud Infrastructure Blockchain service.

        Creates a new Blockchain Platform.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_blockchain_platform = oci.blockchain.BlockchainPlatform("testBlockchainPlatform",
            compartment_id=var["compartment_id"],
            compute_shape=var["blockchain_platform_compute_shape"],
            display_name=var["blockchain_platform_display_name"],
            idcs_access_token=var["blockchain_platform_idcs_access_token"],
            platform_role=var["blockchain_platform_platform_role"],
            ca_cert_archive_text=var["blockchain_platform_ca_cert_archive_text"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["blockchain_platform_description"],
            federated_user_id=oci_identity_user["test_user"]["id"],
            freeform_tags={
                "bar-key": "value",
            },
            is_byol=var["blockchain_platform_is_byol"],
            platform_version=var["blockchain_platform_platform_version"])
        ```

        ## Import

        BlockchainPlatforms can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Blockchain/blockchainPlatform:BlockchainPlatform test_blockchain_platform "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ca_cert_archive_text: Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[str] compute_shape: Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) Platform Instance Description
        :param pulumi.Input[str] display_name: Platform Instance Display name, can be renamed
        :param pulumi.Input[str] federated_user_id: Identifier for a federated user
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] idcs_access_token: IDCS access token with Identity Domain Administrator role
        :param pulumi.Input[bool] is_byol: Bring your own license
        :param pulumi.Input[str] load_balancer_shape: (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] platform_role: Role of platform - founder or participant
        :param pulumi.Input[str] platform_version: Platform version
        :param pulumi.Input[pulumi.InputType['BlockchainPlatformReplicasArgs']] replicas: Number of replicas of service components like Rest Proxy, CA and Console
        :param pulumi.Input[float] storage_size_in_tbs: Storage size in TBs
        :param pulumi.Input[int] total_ocpu_capacity: Number of total OCPUs allocated to the platform cluster
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BlockchainPlatformArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Blockchain Platform resource in Oracle Cloud Infrastructure Blockchain service.

        Creates a new Blockchain Platform.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_blockchain_platform = oci.blockchain.BlockchainPlatform("testBlockchainPlatform",
            compartment_id=var["compartment_id"],
            compute_shape=var["blockchain_platform_compute_shape"],
            display_name=var["blockchain_platform_display_name"],
            idcs_access_token=var["blockchain_platform_idcs_access_token"],
            platform_role=var["blockchain_platform_platform_role"],
            ca_cert_archive_text=var["blockchain_platform_ca_cert_archive_text"],
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            description=var["blockchain_platform_description"],
            federated_user_id=oci_identity_user["test_user"]["id"],
            freeform_tags={
                "bar-key": "value",
            },
            is_byol=var["blockchain_platform_is_byol"],
            platform_version=var["blockchain_platform_platform_version"])
        ```

        ## Import

        BlockchainPlatforms can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Blockchain/blockchainPlatform:BlockchainPlatform test_blockchain_platform "id"
        ```

        :param str resource_name: The name of the resource.
        :param BlockchainPlatformArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BlockchainPlatformArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ca_cert_archive_text: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 compute_shape: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 federated_user_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 idcs_access_token: Optional[pulumi.Input[str]] = None,
                 is_byol: Optional[pulumi.Input[bool]] = None,
                 load_balancer_shape: Optional[pulumi.Input[str]] = None,
                 platform_role: Optional[pulumi.Input[str]] = None,
                 platform_version: Optional[pulumi.Input[str]] = None,
                 replicas: Optional[pulumi.Input[pulumi.InputType['BlockchainPlatformReplicasArgs']]] = None,
                 storage_size_in_tbs: Optional[pulumi.Input[float]] = None,
                 total_ocpu_capacity: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BlockchainPlatformArgs.__new__(BlockchainPlatformArgs)

            __props__.__dict__["ca_cert_archive_text"] = ca_cert_archive_text
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            if compute_shape is None and not opts.urn:
                raise TypeError("Missing required property 'compute_shape'")
            __props__.__dict__["compute_shape"] = compute_shape
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["federated_user_id"] = federated_user_id
            __props__.__dict__["freeform_tags"] = freeform_tags
            if idcs_access_token is None and not opts.urn:
                raise TypeError("Missing required property 'idcs_access_token'")
            __props__.__dict__["idcs_access_token"] = None if idcs_access_token is None else pulumi.Output.secret(idcs_access_token)
            __props__.__dict__["is_byol"] = is_byol
            __props__.__dict__["load_balancer_shape"] = load_balancer_shape
            if platform_role is None and not opts.urn:
                raise TypeError("Missing required property 'platform_role'")
            __props__.__dict__["platform_role"] = platform_role
            __props__.__dict__["platform_version"] = platform_version
            __props__.__dict__["replicas"] = replicas
            __props__.__dict__["storage_size_in_tbs"] = storage_size_in_tbs
            __props__.__dict__["total_ocpu_capacity"] = total_ocpu_capacity
            __props__.__dict__["component_details"] = None
            __props__.__dict__["host_ocpu_utilization_infos"] = None
            __props__.__dict__["is_multi_ad"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["platform_shape_type"] = None
            __props__.__dict__["service_endpoint"] = None
            __props__.__dict__["service_version"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["storage_used_in_tbs"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["idcsAccessToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(BlockchainPlatform, __self__).__init__(
            'oci:Blockchain/blockchainPlatform:BlockchainPlatform',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ca_cert_archive_text: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            component_details: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockchainPlatformComponentDetailArgs']]]]] = None,
            compute_shape: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            federated_user_id: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            host_ocpu_utilization_infos: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockchainPlatformHostOcpuUtilizationInfoArgs']]]]] = None,
            idcs_access_token: Optional[pulumi.Input[str]] = None,
            is_byol: Optional[pulumi.Input[bool]] = None,
            is_multi_ad: Optional[pulumi.Input[bool]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            load_balancer_shape: Optional[pulumi.Input[str]] = None,
            platform_role: Optional[pulumi.Input[str]] = None,
            platform_shape_type: Optional[pulumi.Input[str]] = None,
            platform_version: Optional[pulumi.Input[str]] = None,
            replicas: Optional[pulumi.Input[pulumi.InputType['BlockchainPlatformReplicasArgs']]] = None,
            service_endpoint: Optional[pulumi.Input[str]] = None,
            service_version: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            storage_size_in_tbs: Optional[pulumi.Input[float]] = None,
            storage_used_in_tbs: Optional[pulumi.Input[float]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            total_ocpu_capacity: Optional[pulumi.Input[int]] = None) -> 'BlockchainPlatform':
        """
        Get an existing BlockchainPlatform resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ca_cert_archive_text: Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment Identifier
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockchainPlatformComponentDetailArgs']]]] component_details: Blockchain Platform component details.
        :param pulumi.Input[str] compute_shape: Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] description: (Updatable) Platform Instance Description
        :param pulumi.Input[str] display_name: Platform Instance Display name, can be renamed
        :param pulumi.Input[str] federated_user_id: Identifier for a federated user
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockchainPlatformHostOcpuUtilizationInfoArgs']]]] host_ocpu_utilization_infos: List of OcpuUtilization for all hosts
        :param pulumi.Input[str] idcs_access_token: IDCS access token with Identity Domain Administrator role
        :param pulumi.Input[bool] is_byol: Bring your own license
        :param pulumi.Input[bool] is_multi_ad: True for multi-AD blockchain plaforms, false for single-AD
        :param pulumi.Input[str] lifecycle_details: An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] load_balancer_shape: (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] platform_role: Role of platform - founder or participant
        :param pulumi.Input[str] platform_shape_type: Type of Platform shape - DEFAULT or CUSTOM
        :param pulumi.Input[str] platform_version: Platform version
        :param pulumi.Input[pulumi.InputType['BlockchainPlatformReplicasArgs']] replicas: Number of replicas of service components like Rest Proxy, CA and Console
        :param pulumi.Input[str] service_endpoint: Service endpoint URL, valid post-provisioning
        :param pulumi.Input[str] service_version: The version of the Platform Instance.
        :param pulumi.Input[str] state: The current state of the Platform Instance.
        :param pulumi.Input[float] storage_size_in_tbs: Storage size in TBs
        :param pulumi.Input[float] storage_used_in_tbs: Storage used in TBs
        :param pulumi.Input[str] time_created: The time the the Platform Instance was created. An RFC3339 formatted datetime string
        :param pulumi.Input[str] time_updated: The time the Platform Instance was updated. An RFC3339 formatted datetime string
        :param pulumi.Input[int] total_ocpu_capacity: Number of total OCPUs allocated to the platform cluster
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BlockchainPlatformState.__new__(_BlockchainPlatformState)

        __props__.__dict__["ca_cert_archive_text"] = ca_cert_archive_text
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["component_details"] = component_details
        __props__.__dict__["compute_shape"] = compute_shape
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["federated_user_id"] = federated_user_id
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["host_ocpu_utilization_infos"] = host_ocpu_utilization_infos
        __props__.__dict__["idcs_access_token"] = idcs_access_token
        __props__.__dict__["is_byol"] = is_byol
        __props__.__dict__["is_multi_ad"] = is_multi_ad
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["load_balancer_shape"] = load_balancer_shape
        __props__.__dict__["platform_role"] = platform_role
        __props__.__dict__["platform_shape_type"] = platform_shape_type
        __props__.__dict__["platform_version"] = platform_version
        __props__.__dict__["replicas"] = replicas
        __props__.__dict__["service_endpoint"] = service_endpoint
        __props__.__dict__["service_version"] = service_version
        __props__.__dict__["state"] = state
        __props__.__dict__["storage_size_in_tbs"] = storage_size_in_tbs
        __props__.__dict__["storage_used_in_tbs"] = storage_used_in_tbs
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["total_ocpu_capacity"] = total_ocpu_capacity
        return BlockchainPlatform(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="caCertArchiveText")
    def ca_cert_archive_text(self) -> pulumi.Output[str]:
        """
        Base64 encoded text in ASCII character set of a Thirdparty CA Certificates archive file. The Archive file is a zip file containing third part CA Certificates, the ca key and certificate files used when issuing enrollment certificates (ECerts) and transaction certificates (TCerts). The chainfile (if it exists) contains the certificate chain which should be trusted for this CA, where the 1st in the chain is always the root CA certificate. File list in zip file [ca-cert.pem,ca-key.pem,ca-chain.pem(optional)].
        """
        return pulumi.get(self, "ca_cert_archive_text")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="componentDetails")
    def component_details(self) -> pulumi.Output[Sequence['outputs.BlockchainPlatformComponentDetail']]:
        """
        Blockchain Platform component details.
        """
        return pulumi.get(self, "component_details")

    @property
    @pulumi.getter(name="computeShape")
    def compute_shape(self) -> pulumi.Output[str]:
        """
        Compute shape - STANDARD or ENTERPRISE_SMALL or ENTERPRISE_MEDIUM or ENTERPRISE_LARGE or ENTERPRISE_EXTRA_LARGE
        """
        return pulumi.get(self, "compute_shape")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) Platform Instance Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        Platform Instance Display name, can be renamed
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="federatedUserId")
    def federated_user_id(self) -> pulumi.Output[str]:
        """
        Identifier for a federated user
        """
        return pulumi.get(self, "federated_user_id")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="hostOcpuUtilizationInfos")
    def host_ocpu_utilization_infos(self) -> pulumi.Output[Sequence['outputs.BlockchainPlatformHostOcpuUtilizationInfo']]:
        """
        List of OcpuUtilization for all hosts
        """
        return pulumi.get(self, "host_ocpu_utilization_infos")

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> pulumi.Output[str]:
        """
        IDCS access token with Identity Domain Administrator role
        """
        return pulumi.get(self, "idcs_access_token")

    @property
    @pulumi.getter(name="isByol")
    def is_byol(self) -> pulumi.Output[bool]:
        """
        Bring your own license
        """
        return pulumi.get(self, "is_byol")

    @property
    @pulumi.getter(name="isMultiAd")
    def is_multi_ad(self) -> pulumi.Output[bool]:
        """
        True for multi-AD blockchain plaforms, false for single-AD
        """
        return pulumi.get(self, "is_multi_ad")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="loadBalancerShape")
    def load_balancer_shape(self) -> pulumi.Output[str]:
        """
        (Updatable) Type of Load Balancer shape - LB_100_MBPS or LB_400_MBPS. Default is LB_100_MBPS.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "load_balancer_shape")

    @property
    @pulumi.getter(name="platformRole")
    def platform_role(self) -> pulumi.Output[str]:
        """
        Role of platform - founder or participant
        """
        return pulumi.get(self, "platform_role")

    @property
    @pulumi.getter(name="platformShapeType")
    def platform_shape_type(self) -> pulumi.Output[str]:
        """
        Type of Platform shape - DEFAULT or CUSTOM
        """
        return pulumi.get(self, "platform_shape_type")

    @property
    @pulumi.getter(name="platformVersion")
    def platform_version(self) -> pulumi.Output[str]:
        """
        Platform version
        """
        return pulumi.get(self, "platform_version")

    @property
    @pulumi.getter
    def replicas(self) -> pulumi.Output['outputs.BlockchainPlatformReplicas']:
        """
        Number of replicas of service components like Rest Proxy, CA and Console
        """
        return pulumi.get(self, "replicas")

    @property
    @pulumi.getter(name="serviceEndpoint")
    def service_endpoint(self) -> pulumi.Output[str]:
        """
        Service endpoint URL, valid post-provisioning
        """
        return pulumi.get(self, "service_endpoint")

    @property
    @pulumi.getter(name="serviceVersion")
    def service_version(self) -> pulumi.Output[str]:
        """
        The version of the Platform Instance.
        """
        return pulumi.get(self, "service_version")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the Platform Instance.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="storageSizeInTbs")
    def storage_size_in_tbs(self) -> pulumi.Output[float]:
        """
        Storage size in TBs
        """
        return pulumi.get(self, "storage_size_in_tbs")

    @property
    @pulumi.getter(name="storageUsedInTbs")
    def storage_used_in_tbs(self) -> pulumi.Output[float]:
        """
        Storage used in TBs
        """
        return pulumi.get(self, "storage_used_in_tbs")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time the the Platform Instance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time the Platform Instance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="totalOcpuCapacity")
    def total_ocpu_capacity(self) -> pulumi.Output[int]:
        """
        Number of total OCPUs allocated to the platform cluster
        """
        return pulumi.get(self, "total_ocpu_capacity")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetListingResult',
    'AwaitableGetListingResult',
    'get_listing',
    'get_listing_output',
]

@pulumi.output_type
class GetListingResult:
    """
    A collection of values returned by getListing.
    """
    def __init__(__self__, banners=None, categories=None, compartment_id=None, compatible_architectures=None, default_package_version=None, documentation_links=None, icons=None, id=None, is_featured=None, keywords=None, languages=None, license_model_description=None, links=None, listing_id=None, listing_type=None, long_description=None, name=None, package_type=None, publishers=None, regions=None, release_notes=None, screenshots=None, short_description=None, support_contacts=None, support_links=None, supported_operating_systems=None, system_requirements=None, tagline=None, time_released=None, usage_information=None, version=None, videos=None):
        if banners and not isinstance(banners, list):
            raise TypeError("Expected argument 'banners' to be a list")
        pulumi.set(__self__, "banners", banners)
        if categories and not isinstance(categories, list):
            raise TypeError("Expected argument 'categories' to be a list")
        pulumi.set(__self__, "categories", categories)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compatible_architectures and not isinstance(compatible_architectures, list):
            raise TypeError("Expected argument 'compatible_architectures' to be a list")
        pulumi.set(__self__, "compatible_architectures", compatible_architectures)
        if default_package_version and not isinstance(default_package_version, str):
            raise TypeError("Expected argument 'default_package_version' to be a str")
        pulumi.set(__self__, "default_package_version", default_package_version)
        if documentation_links and not isinstance(documentation_links, list):
            raise TypeError("Expected argument 'documentation_links' to be a list")
        pulumi.set(__self__, "documentation_links", documentation_links)
        if icons and not isinstance(icons, list):
            raise TypeError("Expected argument 'icons' to be a list")
        pulumi.set(__self__, "icons", icons)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_featured and not isinstance(is_featured, bool):
            raise TypeError("Expected argument 'is_featured' to be a bool")
        pulumi.set(__self__, "is_featured", is_featured)
        if keywords and not isinstance(keywords, str):
            raise TypeError("Expected argument 'keywords' to be a str")
        pulumi.set(__self__, "keywords", keywords)
        if languages and not isinstance(languages, list):
            raise TypeError("Expected argument 'languages' to be a list")
        pulumi.set(__self__, "languages", languages)
        if license_model_description and not isinstance(license_model_description, str):
            raise TypeError("Expected argument 'license_model_description' to be a str")
        pulumi.set(__self__, "license_model_description", license_model_description)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if listing_id and not isinstance(listing_id, str):
            raise TypeError("Expected argument 'listing_id' to be a str")
        pulumi.set(__self__, "listing_id", listing_id)
        if listing_type and not isinstance(listing_type, str):
            raise TypeError("Expected argument 'listing_type' to be a str")
        pulumi.set(__self__, "listing_type", listing_type)
        if long_description and not isinstance(long_description, str):
            raise TypeError("Expected argument 'long_description' to be a str")
        pulumi.set(__self__, "long_description", long_description)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if package_type and not isinstance(package_type, str):
            raise TypeError("Expected argument 'package_type' to be a str")
        pulumi.set(__self__, "package_type", package_type)
        if publishers and not isinstance(publishers, list):
            raise TypeError("Expected argument 'publishers' to be a list")
        pulumi.set(__self__, "publishers", publishers)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if release_notes and not isinstance(release_notes, str):
            raise TypeError("Expected argument 'release_notes' to be a str")
        pulumi.set(__self__, "release_notes", release_notes)
        if screenshots and not isinstance(screenshots, list):
            raise TypeError("Expected argument 'screenshots' to be a list")
        pulumi.set(__self__, "screenshots", screenshots)
        if short_description and not isinstance(short_description, str):
            raise TypeError("Expected argument 'short_description' to be a str")
        pulumi.set(__self__, "short_description", short_description)
        if support_contacts and not isinstance(support_contacts, list):
            raise TypeError("Expected argument 'support_contacts' to be a list")
        pulumi.set(__self__, "support_contacts", support_contacts)
        if support_links and not isinstance(support_links, list):
            raise TypeError("Expected argument 'support_links' to be a list")
        pulumi.set(__self__, "support_links", support_links)
        if supported_operating_systems and not isinstance(supported_operating_systems, list):
            raise TypeError("Expected argument 'supported_operating_systems' to be a list")
        pulumi.set(__self__, "supported_operating_systems", supported_operating_systems)
        if system_requirements and not isinstance(system_requirements, str):
            raise TypeError("Expected argument 'system_requirements' to be a str")
        pulumi.set(__self__, "system_requirements", system_requirements)
        if tagline and not isinstance(tagline, str):
            raise TypeError("Expected argument 'tagline' to be a str")
        pulumi.set(__self__, "tagline", tagline)
        if time_released and not isinstance(time_released, str):
            raise TypeError("Expected argument 'time_released' to be a str")
        pulumi.set(__self__, "time_released", time_released)
        if usage_information and not isinstance(usage_information, str):
            raise TypeError("Expected argument 'usage_information' to be a str")
        pulumi.set(__self__, "usage_information", usage_information)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if videos and not isinstance(videos, list):
            raise TypeError("Expected argument 'videos' to be a list")
        pulumi.set(__self__, "videos", videos)

    @property
    @pulumi.getter
    def banners(self) -> Sequence['outputs.GetListingBannerResult']:
        """
        The model for upload data for images and icons.
        """
        return pulumi.get(self, "banners")

    @property
    @pulumi.getter
    def categories(self) -> Sequence[str]:
        """
        Product categories that the listing belongs to.
        """
        return pulumi.get(self, "categories")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compatibleArchitectures")
    def compatible_architectures(self) -> Sequence[str]:
        """
        The list of compatible architectures supported by the listing
        """
        return pulumi.get(self, "compatible_architectures")

    @property
    @pulumi.getter(name="defaultPackageVersion")
    def default_package_version(self) -> str:
        """
        The default package version.
        """
        return pulumi.get(self, "default_package_version")

    @property
    @pulumi.getter(name="documentationLinks")
    def documentation_links(self) -> Sequence['outputs.GetListingDocumentationLinkResult']:
        """
        Links to additional documentation provided by the publisher specifically for the listing.
        """
        return pulumi.get(self, "documentation_links")

    @property
    @pulumi.getter
    def icons(self) -> Sequence['outputs.GetListingIconResult']:
        """
        The model for upload data for images and icons.
        """
        return pulumi.get(self, "icons")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isFeatured")
    def is_featured(self) -> bool:
        """
        Indicates whether the listing is included in Featured Listings.
        """
        return pulumi.get(self, "is_featured")

    @property
    @pulumi.getter
    def keywords(self) -> str:
        """
        Keywords associated with the listing.
        """
        return pulumi.get(self, "keywords")

    @property
    @pulumi.getter
    def languages(self) -> Sequence['outputs.GetListingLanguageResult']:
        """
        Languages supported by the listing.
        """
        return pulumi.get(self, "languages")

    @property
    @pulumi.getter(name="licenseModelDescription")
    def license_model_description(self) -> str:
        """
        A description of the publisher's licensing model for the listing.
        """
        return pulumi.get(self, "license_model_description")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetListingLinkResult']:
        """
        Reference links.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter(name="listingId")
    def listing_id(self) -> str:
        return pulumi.get(self, "listing_id")

    @property
    @pulumi.getter(name="listingType")
    def listing_type(self) -> str:
        """
        The publisher category to which the listing belongs. The publisher category informs where the listing appears for use.
        """
        return pulumi.get(self, "listing_type")

    @property
    @pulumi.getter(name="longDescription")
    def long_description(self) -> str:
        """
        A long description of the listing.
        """
        return pulumi.get(self, "long_description")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Text that describes the resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        The listing's package type.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter
    def publishers(self) -> Sequence['outputs.GetListingPublisherResult']:
        """
        Summary details about the publisher of the listing.
        """
        return pulumi.get(self, "publishers")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.GetListingRegionResult']:
        """
        The regions where the listing is eligible to be deployed.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="releaseNotes")
    def release_notes(self) -> str:
        """
        Release notes for the listing.
        """
        return pulumi.get(self, "release_notes")

    @property
    @pulumi.getter
    def screenshots(self) -> Sequence['outputs.GetListingScreenshotResult']:
        """
        Screenshots of the listing.
        """
        return pulumi.get(self, "screenshots")

    @property
    @pulumi.getter(name="shortDescription")
    def short_description(self) -> str:
        """
        A short description of the listing.
        """
        return pulumi.get(self, "short_description")

    @property
    @pulumi.getter(name="supportContacts")
    def support_contacts(self) -> Sequence['outputs.GetListingSupportContactResult']:
        """
        Contact information to use to get support from the publisher for the listing.
        """
        return pulumi.get(self, "support_contacts")

    @property
    @pulumi.getter(name="supportLinks")
    def support_links(self) -> Sequence['outputs.GetListingSupportLinkResult']:
        """
        Links to support resources for the listing.
        """
        return pulumi.get(self, "support_links")

    @property
    @pulumi.getter(name="supportedOperatingSystems")
    def supported_operating_systems(self) -> Sequence['outputs.GetListingSupportedOperatingSystemResult']:
        """
        The list of operating systems supported by the listing.
        """
        return pulumi.get(self, "supported_operating_systems")

    @property
    @pulumi.getter(name="systemRequirements")
    def system_requirements(self) -> str:
        """
        System requirements for the listing.
        """
        return pulumi.get(self, "system_requirements")

    @property
    @pulumi.getter
    def tagline(self) -> str:
        """
        The tagline of the listing.
        """
        return pulumi.get(self, "tagline")

    @property
    @pulumi.getter(name="timeReleased")
    def time_released(self) -> str:
        """
        The release date of the listing.
        """
        return pulumi.get(self, "time_released")

    @property
    @pulumi.getter(name="usageInformation")
    def usage_information(self) -> str:
        """
        Usage information for the listing.
        """
        return pulumi.get(self, "usage_information")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The version of the listing.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter
    def videos(self) -> Sequence['outputs.GetListingVideoResult']:
        """
        Videos of the listing.
        """
        return pulumi.get(self, "videos")


class AwaitableGetListingResult(GetListingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetListingResult(
            banners=self.banners,
            categories=self.categories,
            compartment_id=self.compartment_id,
            compatible_architectures=self.compatible_architectures,
            default_package_version=self.default_package_version,
            documentation_links=self.documentation_links,
            icons=self.icons,
            id=self.id,
            is_featured=self.is_featured,
            keywords=self.keywords,
            languages=self.languages,
            license_model_description=self.license_model_description,
            links=self.links,
            listing_id=self.listing_id,
            listing_type=self.listing_type,
            long_description=self.long_description,
            name=self.name,
            package_type=self.package_type,
            publishers=self.publishers,
            regions=self.regions,
            release_notes=self.release_notes,
            screenshots=self.screenshots,
            short_description=self.short_description,
            support_contacts=self.support_contacts,
            support_links=self.support_links,
            supported_operating_systems=self.supported_operating_systems,
            system_requirements=self.system_requirements,
            tagline=self.tagline,
            time_released=self.time_released,
            usage_information=self.usage_information,
            version=self.version,
            videos=self.videos)


def get_listing(compartment_id: Optional[str] = None,
                listing_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetListingResult:
    """
    This data source provides details about a specific Listing resource in Oracle Cloud Infrastructure Marketplace service.

    Gets detailed information about a listing, including the listing's name, version, description, and
    resources.

    If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
    you launch the instance, you also need to provide the image ID of the listing resource version that you want.

    Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
    listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
    The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
    its signature, is returned in the response. With the signature for the terms of use agreement for the desired
    listing resource version, create a subscription by issuing a
    [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.

    To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
    Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_listing = oci.Marketplace.get_listing(listing_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The unique identifier for the compartment. It is mandatory when used in non-commercial realms.
    :param str listing_id: The unique identifier for the listing.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['listingId'] = listing_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Marketplace/getListing:getListing', __args__, opts=opts, typ=GetListingResult).value

    return AwaitableGetListingResult(
        banners=__ret__.banners,
        categories=__ret__.categories,
        compartment_id=__ret__.compartment_id,
        compatible_architectures=__ret__.compatible_architectures,
        default_package_version=__ret__.default_package_version,
        documentation_links=__ret__.documentation_links,
        icons=__ret__.icons,
        id=__ret__.id,
        is_featured=__ret__.is_featured,
        keywords=__ret__.keywords,
        languages=__ret__.languages,
        license_model_description=__ret__.license_model_description,
        links=__ret__.links,
        listing_id=__ret__.listing_id,
        listing_type=__ret__.listing_type,
        long_description=__ret__.long_description,
        name=__ret__.name,
        package_type=__ret__.package_type,
        publishers=__ret__.publishers,
        regions=__ret__.regions,
        release_notes=__ret__.release_notes,
        screenshots=__ret__.screenshots,
        short_description=__ret__.short_description,
        support_contacts=__ret__.support_contacts,
        support_links=__ret__.support_links,
        supported_operating_systems=__ret__.supported_operating_systems,
        system_requirements=__ret__.system_requirements,
        tagline=__ret__.tagline,
        time_released=__ret__.time_released,
        usage_information=__ret__.usage_information,
        version=__ret__.version,
        videos=__ret__.videos)


@_utilities.lift_output_func(get_listing)
def get_listing_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                       listing_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetListingResult]:
    """
    This data source provides details about a specific Listing resource in Oracle Cloud Infrastructure Marketplace service.

    Gets detailed information about a listing, including the listing's name, version, description, and
    resources.

    If you plan to launch an instance from an image listing, you must first subscribe to the listing. When
    you launch the instance, you also need to provide the image ID of the listing resource version that you want.

    Subscribing to the listing requires you to first get a signature from the terms of use agreement for the
    listing resource version. To get the signature, issue a [GetAppCatalogListingAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements/GetAppCatalogListingAgreements) API call.
    The [AppCatalogListingResourceVersionAgreements](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersionAgreements) object, including
    its signature, is returned in the response. With the signature for the terms of use agreement for the desired
    listing resource version, create a subscription by issuing a
    [CreateAppCatalogSubscription](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogSubscription/CreateAppCatalogSubscription) API call.

    To get the image ID to launch an instance, issue a [GetAppCatalogListingResourceVersion](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListingResourceVersion/GetAppCatalogListingResourceVersion) API call.
    Lastly, to launch the instance, use the image ID of the listing resource version to issue a [LaunchInstance](https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/Instance/LaunchInstance) API call.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_listing = oci.Marketplace.get_listing(listing_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The unique identifier for the compartment. It is mandatory when used in non-commercial realms.
    :param str listing_id: The unique identifier for the listing.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetStackTfStateResult',
    'AwaitableGetStackTfStateResult',
    'get_stack_tf_state',
    'get_stack_tf_state_output',
]

@pulumi.output_type
class GetStackTfStateResult:
    """
    A collection of values returned by getStackTfState.
    """
    def __init__(__self__, id=None, local_path=None, stack_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if local_path and not isinstance(local_path, str):
            raise TypeError("Expected argument 'local_path' to be a str")
        pulumi.set(__self__, "local_path", local_path)
        if stack_id and not isinstance(stack_id, str):
            raise TypeError("Expected argument 'stack_id' to be a str")
        pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localPath")
    def local_path(self) -> str:
        return pulumi.get(self, "local_path")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> str:
        return pulumi.get(self, "stack_id")


class AwaitableGetStackTfStateResult(GetStackTfStateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStackTfStateResult(
            id=self.id,
            local_path=self.local_path,
            stack_id=self.stack_id)


def get_stack_tf_state(local_path: Optional[str] = None,
                       stack_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStackTfStateResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stack_tf_state = oci.ResourceManager.get_stack_tf_state(stack_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str stack_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the stack.
    """
    __args__ = dict()
    __args__['localPath'] = local_path
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ResourceManager/getStackTfState:getStackTfState', __args__, opts=opts, typ=GetStackTfStateResult).value

    return AwaitableGetStackTfStateResult(
        id=__ret__.id,
        local_path=__ret__.local_path,
        stack_id=__ret__.stack_id)


@_utilities.lift_output_func(get_stack_tf_state)
def get_stack_tf_state_output(local_path: Optional[pulumi.Input[str]] = None,
                              stack_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStackTfStateResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stack_tf_state = oci.ResourceManager.get_stack_tf_state(stack_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str stack_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the stack.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRepositoryPathsResult',
    'AwaitableGetRepositoryPathsResult',
    'get_repository_paths',
    'get_repository_paths_output',
]

@pulumi.output_type
class GetRepositoryPathsResult:
    """
    A collection of values returned by getRepositoryPaths.
    """
    def __init__(__self__, display_name=None, filters=None, folder_path=None, id=None, paths_in_subtree=None, ref=None, repository_id=None, repository_path_collections=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if folder_path and not isinstance(folder_path, str):
            raise TypeError("Expected argument 'folder_path' to be a str")
        pulumi.set(__self__, "folder_path", folder_path)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if paths_in_subtree and not isinstance(paths_in_subtree, bool):
            raise TypeError("Expected argument 'paths_in_subtree' to be a bool")
        pulumi.set(__self__, "paths_in_subtree", paths_in_subtree)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)
        if repository_id and not isinstance(repository_id, str):
            raise TypeError("Expected argument 'repository_id' to be a str")
        pulumi.set(__self__, "repository_id", repository_id)
        if repository_path_collections and not isinstance(repository_path_collections, list):
            raise TypeError("Expected argument 'repository_path_collections' to be a list")
        pulumi.set(__self__, "repository_path_collections", repository_path_collections)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRepositoryPathsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="folderPath")
    def folder_path(self) -> Optional[str]:
        return pulumi.get(self, "folder_path")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="pathsInSubtree")
    def paths_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "paths_in_subtree")

    @property
    @pulumi.getter
    def ref(self) -> Optional[str]:
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter(name="repositoryId")
    def repository_id(self) -> str:
        return pulumi.get(self, "repository_id")

    @property
    @pulumi.getter(name="repositoryPathCollections")
    def repository_path_collections(self) -> Sequence['outputs.GetRepositoryPathsRepositoryPathCollectionResult']:
        """
        The list of repository_path_collection.
        """
        return pulumi.get(self, "repository_path_collections")


class AwaitableGetRepositoryPathsResult(GetRepositoryPathsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryPathsResult(
            display_name=self.display_name,
            filters=self.filters,
            folder_path=self.folder_path,
            id=self.id,
            paths_in_subtree=self.paths_in_subtree,
            ref=self.ref,
            repository_id=self.repository_id,
            repository_path_collections=self.repository_path_collections)


def get_repository_paths(display_name: Optional[str] = None,
                         filters: Optional[Sequence[pulumi.InputType['GetRepositoryPathsFilterArgs']]] = None,
                         folder_path: Optional[str] = None,
                         paths_in_subtree: Optional[bool] = None,
                         ref: Optional[str] = None,
                         repository_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryPathsResult:
    """
    This data source provides the list of Repository Paths in Oracle Cloud Infrastructure Devops service.

    Retrieves a list of files and directories in a repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository_paths = oci.DevOps.get_repository_paths(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        folder_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        paths_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ref=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str folder_path: The fully qualified path to the folder whose contents are returned, including the folder name. For example, /examples is a fully-qualified path to a folder named examples that was created off of the root directory (/) of a repository.
    :param bool paths_in_subtree: Flag to determine if files must be retrived recursively. Flag is False by default.
    :param str ref: The name of branch/tag or commit hash it points to. If names conflict, order of preference is commit > branch > tag. You can disambiguate with "heads/foobar" and "tags/foobar". If left blank repository's default branch will be used.
    :param str repository_id: Unique repository identifier.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['folderPath'] = folder_path
    __args__['pathsInSubtree'] = paths_in_subtree
    __args__['ref'] = ref
    __args__['repositoryId'] = repository_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DevOps/getRepositoryPaths:getRepositoryPaths', __args__, opts=opts, typ=GetRepositoryPathsResult).value

    return AwaitableGetRepositoryPathsResult(
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        folder_path=__ret__.folder_path,
        id=__ret__.id,
        paths_in_subtree=__ret__.paths_in_subtree,
        ref=__ret__.ref,
        repository_id=__ret__.repository_id,
        repository_path_collections=__ret__.repository_path_collections)


@_utilities.lift_output_func(get_repository_paths)
def get_repository_paths_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetRepositoryPathsFilterArgs']]]]] = None,
                                folder_path: Optional[pulumi.Input[Optional[str]]] = None,
                                paths_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                                ref: Optional[pulumi.Input[Optional[str]]] = None,
                                repository_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRepositoryPathsResult]:
    """
    This data source provides the list of Repository Paths in Oracle Cloud Infrastructure Devops service.

    Retrieves a list of files and directories in a repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_repository_paths = oci.DevOps.get_repository_paths(repository_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        folder_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        paths_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        ref=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str folder_path: The fully qualified path to the folder whose contents are returned, including the folder name. For example, /examples is a fully-qualified path to a folder named examples that was created off of the root directory (/) of a repository.
    :param bool paths_in_subtree: Flag to determine if files must be retrived recursively. Flag is False by default.
    :param str ref: The name of branch/tag or commit hash it points to. If names conflict, order of preference is commit > branch > tag. You can disambiguate with "heads/foobar" and "tags/foobar". If left blank repository's default branch will be used.
    :param str repository_id: Unique repository identifier.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDynamicGroupsResult',
    'AwaitableGetDynamicGroupsResult',
    'get_dynamic_groups',
    'get_dynamic_groups_output',
]

@pulumi.output_type
class GetDynamicGroupsResult:
    """
    A collection of values returned by getDynamicGroups.
    """
    def __init__(__self__, compartment_id=None, dynamic_groups=None, filters=None, id=None, name=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if dynamic_groups and not isinstance(dynamic_groups, list):
            raise TypeError("Expected argument 'dynamic_groups' to be a list")
        pulumi.set(__self__, "dynamic_groups", dynamic_groups)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the tenancy containing the group.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dynamicGroups")
    def dynamic_groups(self) -> Sequence['outputs.GetDynamicGroupsDynamicGroupResult']:
        """
        The list of dynamic_groups.
        """
        return pulumi.get(self, "dynamic_groups")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDynamicGroupsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name you assign to the group during creation. The name must be unique across all groups in the tenancy and cannot be changed.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The group's current state.
        """
        return pulumi.get(self, "state")


class AwaitableGetDynamicGroupsResult(GetDynamicGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDynamicGroupsResult(
            compartment_id=self.compartment_id,
            dynamic_groups=self.dynamic_groups,
            filters=self.filters,
            id=self.id,
            name=self.name,
            state=self.state)


def get_dynamic_groups(compartment_id: Optional[str] = None,
                       filters: Optional[Sequence[pulumi.InputType['GetDynamicGroupsFilterArgs']]] = None,
                       name: Optional[str] = None,
                       state: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDynamicGroupsResult:
    """
    This data source provides the list of Dynamic Groups in Oracle Cloud Infrastructure Identity service.

    Lists the dynamic groups in your tenancy. You must specify your tenancy's OCID as the value for
    the compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_dynamic_groups = oci.Identity.get_dynamic_groups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    :param str name: A filter to only return resources that match the given name exactly.
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Identity/getDynamicGroups:getDynamicGroups', __args__, opts=opts, typ=GetDynamicGroupsResult).value

    return AwaitableGetDynamicGroupsResult(
        compartment_id=__ret__.compartment_id,
        dynamic_groups=__ret__.dynamic_groups,
        filters=__ret__.filters,
        id=__ret__.id,
        name=__ret__.name,
        state=__ret__.state)


@_utilities.lift_output_func(get_dynamic_groups)
def get_dynamic_groups_output(compartment_id: Optional[pulumi.Input[str]] = None,
                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDynamicGroupsFilterArgs']]]]] = None,
                              name: Optional[pulumi.Input[Optional[str]]] = None,
                              state: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDynamicGroupsResult]:
    """
    This data source provides the list of Dynamic Groups in Oracle Cloud Infrastructure Identity service.

    Lists the dynamic groups in your tenancy. You must specify your tenancy's OCID as the value for
    the compartment ID (remember that the tenancy is simply the root compartment).
    See [Where to Get the Tenancy's OCID and User's OCID](https://docs.cloud.oracle.com/iaas/Content/API/Concepts/apisigningkey.htm#five).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_dynamic_groups = oci.Identity.get_dynamic_groups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment (remember that the tenancy is simply the root compartment).
    :param str name: A filter to only return resources that match the given name exactly.
    :param str state: A filter to only return resources that match the given lifecycle state.  The state value is case-insensitive.
    """
    ...
